Crate micromap_rawl

Crate micromap_rawl 

Structs

Drain
A draining iterator over the entries of a Map.
IntoIter
Into-iterator over the Map.
IntoKeys
Consuming iterator over the keys of the Map.
IntoValues
Consuming iterator over the values of the Map.
Iter
Iterator over the Map.
IterMut
Mutable Iterator over the Map.
Keys
A read-only iterator over the keys of the Map.
Map
A faster alternative of std::collections::HashMap.
OccupiedEntry
A view into an occupied entry in a Map. It is part of the Entry enum.
Set
A faster alternative of std::collections::HashSet.
SetDrain
SetIntoIter
Into-iterator over the Set.
SetIter
Iterator over the Set.
VacantEntry
A view into a vacant entry in a Map. It is part of the Entry enum.
Values
An iterator over the values of the Map.
ValuesMut
Mutable iterator over the values of the Map.

Enums

Entry
A view into a single entry in a map, which may either be vacant or occupied.